@@ -212,9 +212,10 @@ class Document(metaclass=MetaDocument):
 
         for self_field, other_field in related_fields:
             if self_field.parent:
-                await other_field.document_cls.collection.update_many({
-                    other_field.name: self.shadow_copy[self_field.name]
-                }, {"$set": {other_field.name: self[self_field.name]}})
+                for document in await other_field.document_cls.many({
+                        other_field.name: self.shadow_copy[self_field.name]}):
+                    document[other_field.name] = self[self_field.name]
+                    await document.push_update()
 
     @check_setup
     async def push_update(self):
@@ -269,9 +270,9 @@ class Document(metaclass=MetaDocument):
 
         for self_field, other_field in related_fields:
             if self_field.parent:
-                await other_field.document_cls.collection.delete_many({
-                    other_field.name: self[self_field.name]
-                })
+                for document in await other_field.document_cls.many(**{
+                        other_field.name: self[self_field.name]}):
+                    await document.delete()
 
     async def delete(self):
         """Delete current document and related fields or documents base on related."""
